#! /usr/bin/python
import sys,Config
def send(to,subject,body,fromUser=None,cc="",bcc="",):

    import smtplib
    from email.mime.multipart import MIMEMultipart
    from email.mime.text import MIMEText
    From=fromUser
    try:
            msg = MIMEMultipart('alternative')
            msg['Subject'] = subject
            msg['From'] = From
            #msg['To'] = to one email
            msg['Cc']= cc
            if type(to)==type([]):
                msg['To'] = ', '.join( to) #More than one email
            else:
                msg['To'] = to
            html = body
            part2 = MIMEText(html, 'html')
            msg.attach(part2)
            server = smtplib.SMTP(Config.smtp_host,Config.smtp_port)
            server.ehlo()
            server.starttls()
            server.login(Config.smtp_user, Config.smtp_pass)
            server.sendmail(From, to, msg.as_string())
            if cc!="":
                server.sendmail(From, cc, msg.as_string())
            if bcc!="":
                server.sendmail(From, bcc, msg.as_string())
            server.quit()
	    print "Email Sent"
            return True

    except Exception as exp:
	import traceback
	print traceback.format_exc()
        return False

if __name__=="__main__":
	to=""
	subject="Job done"
	body=""
	fromUser="SGP Notifier<sgpbioinf@gmail.com>"
	cc=""
	bcc=""
	for arg in sys.argv[1:]:
		if "--to" in arg or "-t=" in arg:
			to=arg.split("=")[1]
		elif "--subject" in arg or "-s=" in arg:
                        subject=arg.split("=")[1]
		elif "--from" in arg or "-f=" in arg:
                        fromUser=arg.split("=")[1]
		elif "--body" in arg or "-b=" in arg:
                        body=arg.split("=")[1]
		else:
			print "Invalid Arg '%s'"%arg
			exit(-1)
	if body=="":
		body="<pre>"+"".join(sys.stdin.readlines())+"</pre>"

	send(to,subject,body,fromUser=None,cc="",bcc="",)
		



import sys,ConfigParser,os

config = ConfigParser.RawConfigParser()
if os.path.exists(os.path.expanduser("~/.notify-me.cfg")):
		config.read(os.path.expanduser("~/.notify-me.cfg"))
elif os.path.exists("/etc/notify-me.cfg"):
    config.read("/etc/notify-me.cfg")
else:
    raise Exception("No config file found, put the configuration in /etc/notify-me.cfg or ~/.notify-me.cfg")

notification_key = config.get("Notification-Key","key")
if notification_key.strip()=="":
	print "Warning: No Notification Key Provided, GCM support is disabled."
default_topic=config.get("Notification-Key","default-topic")

smtp_host = config.get("SMTP","SMTP-HOST")
smtp_port = config.get("SMTP","SMTP-PORT")
smtp_user= config.get("SMTP","SMTP-User")
smtp_pass= config.get("SMTP","SMTP-PASS")
default_from=config.get("EMAIL","DEFAULT-FROM")
default_subject=config.get("EMAIL","DEFAULT-SUBJECT")
OK_MESSAGE=config.get("EMAIL","OK-MESSAGE")
ERR_MESSAGE=config.get("EMAIL","ERR-MESSAGE")

Notification_URL=config.get("NOTIFICATION_SERVER","URL")

pushOver_App=config.get("PushOver","App")
pushOver_User=config.get("PushOver","User")




import httplib, urllib
import Config
def push(message):
	print "PushOver running"
	if Config.pushOver_App!="":
		conn = httplib.HTTPSConnection("api.pushover.net:443")
		conn.request("POST", "/1/messages.json",
		  urllib.urlencode({
			"token": Config.pushOver_App,
			"user": Config.pushOver_User,
			"message": message,
		  }), { "Content-type": "application/x-www-form-urlencoded" })
		return conn.getresponse()
	else:
		return "PushOver not enabled"
		
if __name__=="__main__":
	import sys
	push(sys.argv[1])
